@@ -6,7 +6,7 @@ use warnings;
 no warnings 'uninitialized';
 
 
-our $VERSION = '1.01';
+our $VERSION = '1.03';
 
 =head1 NAME
 
@@ -106,12 +106,18 @@ sub run {
 
 	my ($self, $editor) = @_;
 
+	my $tmpl_ref = $self->{'tmpl_file'} 
+		? do { open(FH, "< $self->{'tmpl_file'}"); local $/; <FH> } 
+		: &TEMPLATE;
+
+
 	$self->{template} = HTML::Template->new(
-		scalarref => \TEMPLATE(), 
+		scalarref => \$tmpl_ref, 
 		die_on_bad_params => 0,
 		loop_context_vars => 1,
 	);
 
+
 	$self->{editor} = $editor;
 	
 	# find out what step we are on
@@ -149,6 +155,28 @@ sub set_stylesheet {
 
 
 
+=head2 set_template
+
+Sets an optional template file
+
+Takes a scalar holding the path to an HTML::Template template.
+
+
+B<Example>
+
+  $search->set_template('/www/templates/my.tmpl');
+
+=cut
+
+sub set_template {
+
+	my $self = shift;
+	$self->{tmpl_file} = shift ; 
+}
+
+
+
+
 =head2 add_column  
 
 Adds a new column to your search list table.
